==> sigutils-2.2.7.tar.gz: sigutils-2.2.7/SigUtils/cnpj.py <==
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.03"
__DataAlteracao__ = "24/10/2008"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('cnpj.py\t\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tValidador/formatador de CNPJ '
        else:
           print('\n\ncnpj.py - Validador/formatador de CNPJ \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
       print('\n\ncnpj.py - Validador/formatador de CNPJ \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')

class Cnpj:
    def __init__( self ):
        """
        Classe para testar CNPJ
        """
        pass

    def validar( self,cnpj, force=False ):
        """
        Metodo para validar cnpj
        Force = True, retorna o cnpj com o digito correto
        Testes:

        >>> print Cnpj().validar('61882613000194')
        True
        >>> print Cnpj().validar('61882613000195')
        False
        >>> print Cnpj().validar('53.612.734/0001-98')
        True
        >>> print Cnpj().validar('69.435.154/0001-02')
        True
        >>> print Cnpj().validar('69.435.154/0001-01')
        False
        """
        # definindo algmas variaveis
        lista_validacao_um = [5,4,3,2,9,8,7,6,5,4 ,3,2]
        lista_validacao_dois = [6,5,4,3,2,9,8,7,6,5,4,3,2]
        # Limpando o cnpj
        cnpj = cnpj.replace("-","")
        cnpj = cnpj.replace(".","")
        cnpj = cnpj.replace("/","")
        # encontrando o digito de contorle
        verificadores = cnpj[-2:]
        # verificando o tamano do  cnpj
        if len( cnpj ) != 14:
            return False
        # calculando o primeiro digito
        soma = 0
        id = 0
        for numero in cnpj:
            try:
                lista_validacao_um[id]
            except:
                break
            soma += int(numero) * int(lista_validacao_um[id])
            id += 1
        soma = soma % 11
        if soma < 2:
            digito_um = 0
        else:
            digito_um = 11 - soma
        digito_um = str(digito_um) # convertendo para string para comparacao futura
        if force:
            cnpj = cnpj[:-2] + digito_um + '0'
        # calculando o segundo digito
        # somando as duas listas
        soma = 0
        id = 0
        # somando as duas listas
        for numero in cnpj:
            try:
                lista_validacao_dois[id]
            except:
                break
            soma += int(numero) * int(lista_validacao_dois[id])
            id += 1
        # definindo o digito
        soma = soma % 11
        if soma < 2:
            digito_dois = 0
        else:
            digito_dois = 11 - soma
        digito_dois = str(digito_dois)
        # returnig
        res = False
        if (verificadores == (digito_um + digito_dois )):
            res = True
        if force:
            cnpj = cnpj[:-2] + (digito_um + digito_dois)
            return cnpj
        return res

    def format( self, cnpj ):
        """
        Metodo para formatar o cnpk.
        Testes:

        >>> print Cnpj().format('53612734000198')
        53.612.734/0001-98
        """
        return "%s.%s.%s/%s-%s" % ( cnpj[0:2], cnpj[2:5], cnpj[5:8], cnpj[8:12], cnpj[12:14] )

# testes
import doctest; doctest.testmod()

==> sigutils-3.1.11.tar.gz: sigutils-3.1.11/SigUtils/cnpj.py <==
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.03"
__DataAlteracao__ = "24/10/2008"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print(('cnpj.py\t\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) +
                  '\tValidador/formatador de CNPJ ')
        else:
           print(('\n\ncnpj.py - Validador/formatador de CNPJ \n'
                   + 'Versao: '+ __Versao__ + '\n'
                   + 'Data: '+ __DataAlteracao__ + '\n'))
    except:
       print(('\n\ncnpj.py - Validador/formatador de CNPJ \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n'))


class Cnpj:
    def __init__( self ):
        """
        Classe para testar CNPJ
        """
        pass

    def validar( self,cnpj, force=False ):
        """
        Metodo para validar cnpj
        Force = True, retorna o cnpj com o digito correto
        Testes:

        # >>> print Cnpj().validar('61882613000194')
        # True
        # >>> print Cnpj().validar('61882613000195')
        # False
        # >>> print Cnpj().validar('53.612.734/0001-98')
        # True
        # >>> print Cnpj().validar('69.435.154/0001-02')
        # True
        # >>> print Cnpj().validar('69.435.154/0001-01')
        # False
        """
        # definindo algmas variaveis
        lista_validacao_um = [5,4,3,2,9,8,7,6,5,4 ,3,2]
        lista_validacao_dois = [6,5,4,3,2,9,8,7,6,5,4,3,2]
        # Limpando o cnpj
        cnpj = cnpj.replace("-","")
        cnpj = cnpj.replace(".","")
        cnpj = cnpj.replace("/","")
        # encontrando o digito de contorle
        verificadores = cnpj[-2:]
        # verificando o tamano do  cnpj
        if len( cnpj ) != 14:
            return False
        # calculando o primeiro digito
        soma = 0
        id = 0
        for numero in cnpj:
            try:
                lista_validacao_um[id]
            except:
                break
            soma += int(numero) * int(lista_validacao_um[id])
            id += 1
        soma = soma % 11
        if soma < 2:
            digito_um = 0
        else:
            digito_um = 11 - soma
        digito_um = str(digito_um) # convertendo para string para comparacao futura
        if force:
            cnpj = cnpj[:-2] + digito_um + '0'
        # calculando o segundo digito
        # somando as duas listas
        soma = 0
        id = 0
        # somando as duas listas
        for numero in cnpj:
            try:
                lista_validacao_dois[id]
            except:
                break
            soma += int(numero) * int(lista_validacao_dois[id])
            id += 1
        # definindo o digito
        soma = soma % 11
        if soma < 2:
            digito_dois = 0
        else:
            digito_dois = 11 - soma
        digito_dois = str(digito_dois)
        # returnig
        res = False
        if (verificadores == (digito_um + digito_dois )):
            res = True
        if force:
            cnpj = cnpj[:-2] + (digito_um + digito_dois)
            return cnpj
        return res

    def format( self, cnpj ):
        """
        Metodo para formatar o cnpk.
        Testes:

        # >>> print Cnpj().format('53612734000198')
        # 53.612.734/0001-98
        """
        return "%s.%s.%s/%s-%s" % ( cnpj[0:2], cnpj[2:5], cnpj[5:8], cnpj[8:12], cnpj[12:14] )

# testes
import doctest; doctest.testmod()
